@@ -9,7 +9,7 @@ import collections
 
 from openpyxl.styles import Alignment
 from openpyxl.worksheet.worksheet import Worksheet
-from utils.tool import char_to_num, num_to_pos_char
+from simple_export.utils.tool import char_to_num, num_to_pos_char
 from openpyxl.cell import Cell
 
 class dynamic_method():
